#!/bin/sh

# Install curl
apk add --no-cache curl

# Use environment variables
ELASTIC_PASSWORD=${ELASTIC_PASSWORD}
USER_PASSWORD=${USER_PASSWORD}
KIBANA_SYSTEM_PASSWORD=${KIBANA_SYSTEM_PASSWORD}

# Debug statements (optional)
echo "ELASTIC_PASSWORD is: $ELASTIC_PASSWORD"
echo "USER_PASSWORD is: $USER_PASSWORD"
echo "KIBANA_SYSTEM_PASSWORD is: $KIBANA_SYSTEM_PASSWORD"

# Wait for Elasticsearch to be available
until curl -s -u elastic:$ELASTIC_PASSWORD http://es01:9200 -o /dev/null; do
  echo 'Waiting for Elasticsearch...'
  sleep 5
done
echo 'Elasticsearch is up'

# Check if 'es_user' user exists
STATUS_CODE=$(curl -s -o /dev/null -w '%{http_code}' -u elastic:$ELASTIC_PASSWORD -X GET http://es01:9200/_security/user/es_user)
if [ "$STATUS_CODE" -eq 200 ]; then
  echo 'User es_user already exists'
else
  # Create 'es_user' user
  curl -s -X POST -u elastic:$ELASTIC_PASSWORD \
    http://es01:9200/_security/user/es_user \
    -H 'Content-Type: application/json' \
    -d "{\"password\":\"$USER_PASSWORD\",\"roles\":[\"superuser\"]}"
  echo 'User es_user created'
fi

# Set password for 'kibana_system' user
curl -s -X POST -u elastic:$ELASTIC_PASSWORD \
  http://es01:9200/_security/user/kibana_system/_password \
  -H 'Content-Type: application/json' \
  -d "{\"password\":\"$KIBANA_SYSTEM_PASSWORD\"}"
echo 'Password for kibana_system user set'
